@@ -49,14 +49,14 @@ class PackageManager(interfaces.PackageManager):
         command.run_with_sudo(args, test=self._test)
 
     def update(self):
-        command.run_with_sudo(["apt-get", "dist-upgrade"], test=self._test)
+        command.run_with_sudo(["apt-get", "update"], test=self._test)
 
         args = ["apt-get"]
 
         if not self._interactive:
             args.append("-y")
 
-        args.append("upgrade")
+        args.append("dist-upgrade")
 
         command.run_with_sudo(args, test=self._test)
 
